import {
  FocusAwareStatusBar,
  SafeAreaView,
  ScrollView,
  View,
} from '@/components/ui';
import * as React from 'react';
import { Keyboard, Text, TouchableWithoutFeedback } from 'react-native';
import PrimeButton from '@/library/prime-button';
import PrimeLabel from '@/library/prime-label';
import PrimeSocialButton from '@/library/prime-social-button';
import PrimeTextField, { StatusConfig } from '@/library/prime-textfield';
import PrimeTopNavigation from '@/library/prime-top-navigation';
import PrimeSwitch from '@/library/prime-switch';
import { useSharedValue } from 'react-native-reanimated';
import PrimeCheckBox from '@/library/prime-check-box';
import PrimeMainPageHeader from '@/library/prime-main-page-header';
import PrimeSubPageHeader from '@/library/prime-sub-page-header';
import PrimeText from '@/library/prime-text';

const IconDummyComponent = () => {
  return <View className="w-6 h-6 bg-red-500 rounded-full" />;
};
const IconDummyComponent2 = () => {
  return <View className="w-6 h-6 bg-blue-500 rounded-full" />;
};

export default function Paper() {
  const [text, setText] = React.useState('');
  const [passwordText, setPasswordText] = React.useState('');
  const [passwordVisible, setPasswordVisible] = React.useState(true);
  const [countText, setCountText] = React.useState('');
  const [passwordStatusConfig, setPasswordStatusConfig] =
    React.useState<StatusConfig>({
      status: 'none',
      message: '',
    });
  const [statusConfig, setStatusConfig] = React.useState<StatusConfig>({
    status: 'none',
    message: '',
  });

  interface IdState {
    first: string;
    second: string;
  }

  const [idValue, setIdValue] = React.useState({ first: '', second: '' });
  const [idStatusConfig, setIdStatusConfig] = React.useState<StatusConfig>({
    status: 'none',
    message: '',
  });

  function handlePasswordChange(inputText: string) {
    setPasswordText(inputText);
    if (inputText.length >= 8) {
      setPasswordStatusConfig({
        status: 'success',
        message: '유효한 비밀번호입니다.',
      });
    } else {
      setPasswordStatusConfig({
        status: 'error',
        message: '비밀번호는 최소 8자 이상이어야 합니다.',
      });
    }
  }

  function handlePasswordClear() {
    setPasswordText('');
    setPasswordStatusConfig({
      status: 'none',
      message: '',
    });
  }

  const handleIdChange = {
    onFirstChange: (text: string) => {
      setIdValue((prev) => ({
        ...prev,
        first: text,
      }));
      validateId(text, idValue.second);
    },
    onSecondChange: (text: string) => {
      setIdValue((prev) => ({
        ...prev,
        second: text,
      }));
      validateId(idValue.first, text);
    },
  };

  function validateId(first: string, second: string) {
    // ID 유효성 검사: 앞 6자리, 뒤 1자리
    if (first.length === 6 && second.length === 1) {
      setIdStatusConfig({
        status: 'success',
        message: '유효한 주민등록번호입니다.',
      });
    } else {
      setIdStatusConfig({
        status: 'error',
        message: '앞 6자리와 뒤 1자리를 입력해야 합니다.',
      });
    }
  }

  function handleClear() {
    setIdValue({ first: '', second: '' });
    setIdStatusConfig({
      status: 'none',
      message: '',
    });
  }

  const handleCustomValidation = (text: string) => {
    if (text.length <= 10 && /^[a-zA-Z]*$/.test(text)) {
      // 예: 10자 이하, 알파벳만 허용
      setCountText(text);
    }
  };

  // Top Navigation
  const TestComponent = () => {
    return <View className="w-[24px] h-[24px] bg-blue-500 rounded-full" />;
  };

  const [activeTab, setActiveTab] = React.useState('테스트');

  // Switch
  const isOn = useSharedValue(true);

  const handlePress = () => {
    isOn.value = !isOn.value;
    console.log(isOn.value);
  };

  // checkbox
  const [checked, setChecked] = React.useState(true);

  const handleTextChange = (inputText: string) => {
    setText(inputText);
    if (inputText.length < 3) {
      setStatusConfig({
        status: 'error',
        message: '에러 메시지 표기',
      });
    } else {
      // 상황에 따라 성공 표기를 하고싶지 않다면, status는 'none'으로 설정, message는 ''로 설정
      setStatusConfig({
        status: 'success',
        message: '성공 메시지 표기',
      });
    }
  };

  return (
    <PrimeTopNavigation backgroundColor="white" barStyle={'dark-content'}>
      <PrimeMainPageHeader
        tabTitle={['테스트', '테스트2']}
        // tabTitle={['테스트']}
        activeTab={activeTab}
        onTabChange={setActiveTab}
        funcComponent={[
          <TestComponent />,
          <TestComponent />,
          <TestComponent />,
        ]}
      />
      {/* <PrimeSubPageHeader
        title={'Middle Title'}
        funcComponent={[
          <TestComponent />,
          <TestComponent />,
          <TestComponent />,
        ]}
      /> */}
      <TouchableWithoutFeedback onPress={Keyboard.dismiss}>
        <View className="flex-1 justify-center gap-4 px-[16px]">
          {activeTab === '테스트' && (
            <ScrollView>
              {/* 정적 라벨 */}
              <PrimeLabel
                value={'라벨 텍스트'}
                labelClassName="text-sm"
                isLabelOnly
                required
              />

              <Text style={{ fontFamily: 'pretendard100' }}>Pretendard100</Text>
              <Text style={{ fontFamily: 'pretendard200' }}>Pretendard200</Text>
              <Text style={{ fontFamily: 'pretendard300' }}>Pretendard300</Text>
              <Text style={{ fontFamily: 'pretendard400' }}>Pretendard400</Text>
              <Text style={{ fontFamily: 'pretendard500' }}>Pretendard500</Text>
              <Text style={{ fontFamily: 'pretendard600' }}>Pretendard600</Text>
              <Text style={{ fontFamily: 'pretendard700' }}>Pretendard700</Text>
              {/* <Text style={{ fontFamily: 'pretendard800' }}>Pretendard800</Text> */}
              <Text className="font-pretendard800">Pretendard800</Text>

              <Text className="text-[16px]">REM / 16</Text>
              <Text style={{ fontSize: 16 }}>REM / 16</Text>
              <Text className="text-[2rem]">REM / 14</Text>
              <Text>REM / 14</Text>
              <Text className="text-[14px]">REM / 14</Text>

              {/* <Text style={{ fontFamily: 'pretendard200' }}>Pretendard200</Text>
              <Text style={{ fontFamily: 'pretendard300' }}>Pretendard300</Text>
              <Text style={{ fontFamily: 'pretendard400' }}>Pretendard400</Text>
              <Text style={{ fontFamily: 'pretendard500' }}>Pretendard500</Text>
              <Text style={{ fontFamily: 'pretendard600' }}>Pretendard600</Text>
              <Text style={{ fontFamily: 'pretendard700' }}>Pretendard700</Text>
              <Text style={{ fontFamily: 'pretendard800' }}>Pretendard800</Text>
              <Text style={{ fontFamily: 'pretendard900' }}>Pretendard900</Text> */}

              {/* 카운팅 라벨 */}
              <PrimeLabel
                value={countText}
                onChangeText={handleCustomValidation}
                labelClassName="text-lg"
                charactorCount={true}
                maxCharactorCount={10}
              />

              <PrimeCheckBox
                // backgroundColor={'orange'}
                // backgroundColor={'red'}
                // disabled={true}
                backgroundColor={'brand-primary-default'}
                className="rounded-full"
                checked={checked}
                onChange={() => {
                  console.log(!checked ? 'checked' : 'unchecked');
                  setChecked(!checked);
                }}
              />
              <PrimeSwitch
                trackColors={{ on: '#10B981', off: '#E5E7EB' }}
                // disabled={true}
                value={isOn}
                onPress={handlePress}
                style={{ width: 42, height: 24, padding: 3 }}
              />

              <View className="flex-1 bg-blue-300">
                {/* 새로운 텍스트 프리셋 적용 */}
                {/* Display */}
                <PrimeText face={'display'} size="small">
                  Display small
                </PrimeText>
                <PrimeText face={'display'} size="medium">
                  Display medium
                </PrimeText>
                <PrimeText face={'display'} size="large">
                  Display large
                </PrimeText>
                <PrimeText face={'display'} size="xlarge">
                  Display xlarge
                </PrimeText>

                {/* Title */}
                <PrimeText face={'title'} size="xsmall">
                  Title xsmall
                </PrimeText>
                <PrimeText face={'title'} size="small">
                  Title small
                </PrimeText>
                <PrimeText face={'title'} size="medium">
                  Title medium
                </PrimeText>
                <PrimeText face={'title'} size="large">
                  Title large
                </PrimeText>
                <PrimeText face={'title'} size="xlarge">
                  Title xlarge
                </PrimeText>
                <PrimeText face={'title'} size="2xlarge">
                  Title 2xlarge
                </PrimeText>

                {/* Body */}
                <PrimeText face={'body'} size="xsmall">
                  body xsmall
                </PrimeText>
                <PrimeText face={'body'} size="small">
                  body small
                </PrimeText>
                <PrimeText face={'body'} size="medium">
                  body medium
                </PrimeText>
                <PrimeText face={'body'} size="large">
                  body large
                </PrimeText>
                <PrimeText face={'body'} size="xlarge">
                  body xlarge
                </PrimeText>
                <PrimeText face={'body'} size="2xlarge">
                  body 2xlarge
                </PrimeText>

                {/* Paragraph */}
                <PrimeText face={'paragraph'} size="xsmall">
                  paragraph xsmall
                </PrimeText>
                <PrimeText face={'paragraph'} size="small">
                  paragraph small
                </PrimeText>
                <PrimeText face={'paragraph'} size="medium">
                  paragraph medium
                </PrimeText>
                <PrimeText face={'paragraph'} size="large">
                  paragraph large
                </PrimeText>
                <PrimeText face={'paragraph'} size="xlarge">
                  paragraph xlarge
                </PrimeText>
                <PrimeText face={'paragraph'} size="2xlarge">
                  paragraph 2xlarge
                </PrimeText>

                {/* Caption */}
                <PrimeText face={'caption'} size="xsmall">
                  caption xsmall
                </PrimeText>
                <PrimeText face={'caption'} size="small">
                  caption small
                </PrimeText>
                <PrimeText face={'caption'} size="medium">
                  caption medium
                </PrimeText>
              </View>

              {/* <Text className="text-prime-text-10">text-Prime Text 10</Text>
              <Text className="text-prime-text-12">text-Prime Text 12</Text>
              <Text className="text-prime-text-14">text-Prime Text 14</Text>
              <Text className="text-prime-text-16">text-Prime Text 16</Text>
              <Text className="text-prime-text-20">text-Prime Text 20</Text>
              <Text className="text-prime-text-24">text-Prime Text 24</Text>
              <Text className="text-prime-text-32">text-Prime Text 32</Text>
              <Text className="text-prime-paragraph-13">
                text-prime-paragraph-13
              </Text>
              <Text className="text-prime-paragraph-14">
                text-prime-paragraph-14
              </Text>
              <Text className="text-prime-paragraph-15">
                text-prime-paragraph-15
              </Text>
              <Text className="text-prime-paragraph-16">
                text-prime-paragraph-16
              </Text>
              <Text className="text-prime-paragraph-18">
                text-prime-paragraph-18
              </Text> */}
            </ScrollView>
          )}

          {activeTab === '테스트2' && (
            <>
              <PrimeTextField
                label={{
                  text: '주민등록번호',
                  style: { fontSize: 14 },
                  required: true,
                }}
                input={{
                  mode: 'id',
                  idValue: idValue,
                  onIdChange: {
                    onFirstChange: handleIdChange.onFirstChange,
                    onSecondChange: handleIdChange.onSecondChange,
                  },
                  border: 'border-2 border-gray-700',
                }}
                statusConfig={idStatusConfig}
                onClear={handleClear}
              />

              <PrimeTextField
                label={{
                  text: '라벨',
                  className: 'text-sm',
                }}
                input={{
                  mode: 'default',
                  value: text,
                  placeholder: '홍길동',
                }}
                statusConfig={statusConfig}
                onClear={() => {
                  setText('');
                  setStatusConfig({
                    status: 'none',
                    message: '',
                  });
                }}
                onChangeText={handleTextChange}
              />

              <PrimeTextField
                label={{
                  text: '비밀번호',
                }}
                input={{
                  mode: 'password',
                  value: passwordText,
                  placeholder: '비밀번호',
                  isSecureTextEntry: passwordVisible,
                  onSecureTextEntryChange: setPasswordVisible,
                }}
                statusConfig={passwordStatusConfig}
                onChangeText={handlePasswordChange}
                onClear={handlePasswordClear}
              />

              <View className="flex-row gap-4  w-full">
                <PrimeButton
                  // disabled={true}
                  // loading={true}
                  variant="primaryLow"
                  text={'테스트'}
                  shape={'round'}
                  className="flex-1"
                  // backgroundColor={'brand-primary-default'}
                  // textColor={'blue'}
                  onPress={() => console.log('테스트')}
                />
                <PrimeButton
                  // disabled={true}
                  // loading={true}
                  variant="primaryLow"
                  text={'테스���'}
                  className="flex-1"
                  shape={'round'}
                  // backgroundColor={'brand-primary-default'}
                  // textColor={'blue'}
                  onPress={() => console.log('테스트')}
                />
              </View>

              <PrimeButton
                // disabled={true}
                // loading={true}
                variant="primaryLow"
                text={'테스트'}
                shape={'round'}
                // backgroundColor={'brand-primary-default'}
                // textColor={'blue'}
                onPress={() => console.log('테스트')}
              />

              <PrimeSocialButton
                type="google"
                onPress={() => console.log('카카오 로그인')}
              />
            </>
          )}
        </View>
      </TouchableWithoutFeedback>
    </PrimeTopNavigation>
  );
}
