import * as React from 'react';
import { TouchableOpacity, View } from 'react-native';
import PrimeLabel from './prime-label';
import { TopHeaderLeftArrowIcon } from './icons/top-header-left-arrow';

interface PrimeSubPageHeaderProps {
  height?: string;
  componentGap?: number;
  title?: string;
  funcComponent?: React.ReactNode[];
  backgroundColor?: any;
}

const PrimeSubPageHeader = React.forwardRef<View, PrimeSubPageHeaderProps>(
  ({ height, componentGap, title, funcComponent, backgroundColor }, ref) => {
    return (
      <View
        className={`flex w-full flex-row items-center justify-between px-[20px] ${height ? height : 'h-[48px]'}`}
        ref={ref}
      >
        <View className="flex flex-row items-center gap-4">
          <TouchableOpacity
            onPress={() => {
              console.log('go back');
            }}
          >
            <TopHeaderLeftArrowIcon />
          </TouchableOpacity>
        </View>
        {title && (
          <View className="absolute left-0 right-0 flex items-center">
            <PrimeLabel
              value={title}
              labelClassName="text-[17px]"
              isLabelOnly
            />
          </View>
        )}
        <View className="flex-1 flex flex-row items-center justify-end gap-4">
          {funcComponent &&
            funcComponent.map((comp, index) => <View key={index}>{comp}</View>)}
        </View>
      </View>
    );
  },
);

export default PrimeSubPageHeader;
