import * as React from 'react';
import { Text } from 'react-native';
import { getColor } from './style-utils';

type PrimeTextFace = 'display' | 'title' | 'body' | 'paragraph' | 'caption';
type DisplaySize = 'small' | 'medium' | 'large' | 'xlarge';
type TitleSize = 'xsmall' | 'small' | 'medium' | 'large' | 'xlarge' | '2xlarge';
type BodySize = 'xsmall' | 'small' | 'medium' | 'large' | 'xlarge' | '2xlarge';
type ParagraphSize =
  | 'xsmall'
  | 'small'
  | 'medium'
  | 'large'
  | 'xlarge'
  | '2xlarge';
type CaptionSize = 'xsmall' | 'small' | 'medium';

type TextSize = ParagraphSize;

interface PrimeTextProps {
  face?: PrimeTextFace;
  size?: TextSize;
  textColor?: string;
  children: string;
}

type PrimeTextSizeMap = {
  display: Record<DisplaySize, string>;
  title: Record<TitleSize, string>;
  body: Record<BodySize, string>;
  paragraph: Record<ParagraphSize, string>;
  caption: Record<CaptionSize, string>;
};

const PRIME_TEXT_FACE_PRESETS: PrimeTextSizeMap = {
  display: {
    small: 'text-prime-text-36',
    medium: 'text-prime-text-40',
    large: 'text-prime-text-48',
    xlarge: 'text-prime-text-56',
  },
  title: {
    xsmall: 'text-prime-text-16',
    small: 'text-prime-text-18',
    medium: 'text-prime-text-20',
    large: 'text-prime-text-22',
    xlarge: 'text-prime-text-24',
    '2xlarge': 'text-prime-text-28',
  },
  body: {
    xsmall: 'text-prime-text-13',
    small: 'text-prime-text-14',
    medium: 'text-prime-text-15',
    large: 'text-prime-text-16',
    xlarge: 'text-prime-text-18',
    '2xlarge': 'text-prime-text-20',
  },
  paragraph: {
    xsmall: 'text-prime-text-13',
    small: 'text-prime-text-14',
    medium: 'text-prime-text-15',
    large: 'text-prime-text-16',
    xlarge: 'text-prime-text-18',
    '2xlarge': 'text-prime-text-20',
  },
  caption: {
    xsmall: 'text-prime-text-10',
    small: 'text-prime-text-11',
    medium: 'text-prime-text-12',
  },
};

// interface PrimeSocialButtonProps {
//   type: SocialButtonType;
//   onPress: () => void;
//   disabled?: boolean;
//   loading?: boolean;
//   className?: string;
// }

export default function PrimeText({
  face = 'display',
  size = 'medium',
  textColor = 'black',
  children,
}: PrimeTextProps) {
  const preset = PRIME_TEXT_FACE_PRESETS[face][size];

  return (
    <Text className={`${preset}`} style={{ color: getColor(textColor) }}>
      {children}
    </Text>
  );
}
