import * as React from 'react';
import { Platform, StatusBarStyle, View, ViewStyle } from 'react-native';
import { FocusAwareStatusBar, SafeAreaView } from '../components/ui';
import { getColor } from './style-utils';

interface PrimeTopNavigationProps {
  children: React.ReactNode;
  backgroundColor?: string;
  className?: any;
  barStyle?: null | StatusBarStyle | undefined;
}

const PrimeTopNavigation = React.forwardRef<View, PrimeTopNavigationProps>(
  (
    {
      children,
      backgroundColor = '#000000',
      className,
      barStyle = 'dark-content',
    },
    ref,
  ) => {
    const isDarkBackground = backgroundColor === '#000000';

    return (
      <View
        ref={ref}
        className={`flex-1  ${className}`}
        style={[{ backgroundColor: getColor(backgroundColor) }]}
      >
        <FocusAwareStatusBar
          barStyle={barStyle}
          backgroundColor={backgroundColor}
          translucent={false}
        />
        <SafeAreaView
          style={{ flex: 1, backgroundColor: getColor(backgroundColor) }}
        >
          {children}
        </SafeAreaView>
      </View>
    );
  },
);

export default PrimeTopNavigation;
